@@ -1,21 +1,22 @@
 #' Find spots based on threshold and minimum total intensity
 #'
-#' @param img image array
-#' @param mask mask
-#' @param thresh.offset threshold for minimum voxel intensity
+#' @param img image array.
+#' @param mask mask array.
+#' @param thresh.offset threshold for minimum voxel intensity.
+#' @param window Half width and height of the moving rectangular window.
 #' @param min.sum.intensity threshold for minimum total spot intensity
-#' @param zero if NA, background is set to NA, if 0,background is set to 0
-#' @param max.spots find max.spots spots with highest total intensity
+#' @param zero if NA, background is set to NA, if 0, background is set to 0.
+#' @param max.spots find max.spots spots with highest total intensity.
 #' @param return "mask" returns binarized mask, "intensity" returns intensity for spots, zero or NA otherwise
-#'        "label" return labeled (numbered) spots 
+#'        "label" return labeled (numbered) spots.
 #'
 #' @return array
 #' @export
 #'
-spots<-function(img, mask, thresh.offset=0.1, min.sum.intensity=0, zero=NA, max.spots=NULL, return="full")
+spots<-function(img, mask, thresh.offset=0.1, window=c(5,5), min.sum.intensity=0, zero=NA, max.spots=NULL, return="intensity")
 {
   img[mask==0]<-0
-  spots<-EBImage::thresh(img,offset=thresh.offset)
+  spots<-EBImage::thresh(img, offset=thresh.offset, w=window[1], h=window[2])
 
   s<-bioimagetools::bwlabel3d(spots)
   cm<-bioimagetools::cmoments3d(s,img)
